@@ -338,7 +338,7 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "PUSH_ARG_MULNUM_DOUBLE",
     "CALL_CLASS_METHOD_BY_ID",
     "CALL_INSTANCE_METHOD_BY_ID",
-    "CALL_INSTANCE_METHOD_BY_SIGNATURE",
+    "CALL_INSTANCE_METHOD_BY_NAME",
     "GET_ARG_BYTE",
     "GET_ARG_SHORT",
     "GET_ARG_INT",
@@ -353,6 +353,13 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "GET_ARG_MULNUM_LONG",
     "GET_ARG_MULNUM_FLOAT",
     "GET_ARG_MULNUM_DOUBLE",
+    "GET_ARG_OPTIONAL_BYTE",
+    "GET_ARG_OPTIONAL_SHORT",
+    "GET_ARG_OPTIONAL_INT",
+    "GET_ARG_OPTIONAL_LONG",
+    "GET_ARG_OPTIONAL_FLOAT",
+    "GET_ARG_OPTIONAL_DOUBLE",
+    "GET_ARG_OPTIONAL_OBJECT",
     "RETURN_VOID",
     "RETURN_BYTE",
     "RETURN_SHORT",
