@@ -49,7 +49,7 @@ SPVM::LongList - Dynamic long Array
   
 =head1 Description
 
-L<LongList|SPVM::LongList> is a dynamic C<long> array.
+C<LongList> is a dynamic C<long> array.
 
 =head1 Fields
 
@@ -72,9 +72,9 @@ The values. This is the internally used array, but it can be manipulated directl
 
 =head2 new
 
-  static method new : LongList ($array : long[]...)
+  static method new : LongList ($array = undef : long[])
 
-Create a new L<LongList|SPVM::LongList> object with a C<long> array.
+Create a new C<LongList> object with a C<long> array.
 
 Internally, a new array is created, and each element of the specified array is copied to the new array.
 
@@ -84,13 +84,12 @@ B<Examples:>
 
   my $list = LongList->new;
   my $list = LongList->new([(long)1, 2, 3]);
-  my $list = LongList->new(undef);
 
 =head2 new_len
 
   static method new_len : LongList ($length : int)
 
-Create a new L<LongList|SPVM::LongList> object with the length.
+Create a new C<LongList> object with the length.
 
 The length must be greater than or equal to C<0>. Otherwise an excpetion will be thrown.
 
